==> haskell-authenticate-oauth-1.6-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-authenticate-oauth.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: authenticate-oauth
version: 1.6
id: authenticate-oauth-1.6-GDVATr2PHzcKWehHMUAfP
key: authenticate-oauth-1.6-GDVATr2PHzcKWehHMUAfP
license: BSD-3-Clause
maintainer: Hiromi Ishii, Artem Chirkin
author: Hiromi Ishii
stability: Stable
homepage: http://github.com/yesodweb/authenticate
synopsis: Library to authenticate with OAuth for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate-oauth>.
category: Web
abi: 6964202a06015fbb1996811043b2f244
exposed: True
exposed-modules:
    Web.Authenticate.OAuth Web.Authenticate.OAuth.IO
import-dirs: /usr/lib/ghc-8.4.3/site-local/authenticate-oauth-1.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/authenticate-oauth-1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/authenticate-oauth-1.6
hs-libraries: HSauthenticate-oauth-1.6-GDVATr2PHzcKWehHMUAfP
depends:
    RSA-2.3.0-EUVyfwx1PD02SQJSuFvkv SHA-1.6.4.4-J97i4k52krALB5u9VxmQ73
    base-4.11.1.0 base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 bytestring-0.10.8.2
    crypto-pubkey-types-0.4.3-LkrpxkstMFs2EY3Cpy8xyF
    data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0
    http-client-0.5.13-GyLA8HATX9cHiBKliNKWxB
    http-types-0.12.1-9rf2Bc0mANC4pe1MDcYyOl
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV time-1.8.0.2 transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
abi-depends: RSA-2.3.0-EUVyfwx1PD02SQJSuFvkv=1c85c143d0f47b276219190e5d025ccc
             SHA-1.6.4.4-J97i4k52krALB5u9VxmQ73=7fdfeaf1e3416ffd434c90cf824fb303
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             crypto-pubkey-types-0.4.3-LkrpxkstMFs2EY3Cpy8xyF=bc5c49359ce9e6e9788806a490afac94
             data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0=e2403b7ea90422302496191f03ca1dc3
             http-client-0.5.13-GyLA8HATX9cHiBKliNKWxB=c70ea065b1fde639c4b7cb3ed9f544b5
             http-types-0.12.1-9rf2Bc0mANC4pe1MDcYyOl=f077e3c0d9d6c05be2dfc7d9c3ae67ad
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
haddock-interfaces: /usr/share/doc/haskell-authenticate-oauth/html/authenticate-oauth.haddock
haddock-html: /usr/share/doc/haskell-authenticate-oauth/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-oauth-1.6-18-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-authenticate-oauth.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: authenticate-oauth
version: 1.6
id: authenticate-oauth-1.6-9iq0tVUyCSc9oOcocsnfy5
key: authenticate-oauth-1.6-9iq0tVUyCSc9oOcocsnfy5
license: BSD-3-Clause
maintainer: Hiromi Ishii, Artem Chirkin
author: Hiromi Ishii
stability: Stable
homepage: http://github.com/yesodweb/authenticate
synopsis: Library to authenticate with OAuth for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate-oauth>.
category: Web
abi: 2aea264d3bfcd7314f197ce5a6c4840f
exposed: True
exposed-modules:
    Web.Authenticate.OAuth Web.Authenticate.OAuth.IO
import-dirs: /usr/lib/ghc-8.4.3/site-local/authenticate-oauth-1.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/authenticate-oauth-1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/authenticate-oauth-1.6
hs-libraries: HSauthenticate-oauth-1.6-9iq0tVUyCSc9oOcocsnfy5
depends:
    RSA-2.3.0-2fbLTPZ9IqCF8OkpZTRzB SHA-1.6.4.4-J97i4k52krALB5u9VxmQ73
    base-4.11.1.0 base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 bytestring-0.10.8.2
    crypto-pubkey-types-0.4.3-HQUBpjzjZUT3Ttjod5CYqT
    data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0
    http-client-0.5.13-3Kl4d46bfFOKlGDkbjwGGp
    http-types-0.12.1-1FEEescNY7H9pB2LVhivNI
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV time-1.8.0.2 transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
abi-depends: RSA-2.3.0-2fbLTPZ9IqCF8OkpZTRzB=445009fdf31ed5e9cb8e3fcd099f6011
             SHA-1.6.4.4-J97i4k52krALB5u9VxmQ73=7fdfeaf1e3416ffd434c90cf824fb303
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             crypto-pubkey-types-0.4.3-HQUBpjzjZUT3Ttjod5CYqT=f652c9ce9a440331e1b8f144a8a422f1
             data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0=e2403b7ea90422302496191f03ca1dc3
             http-client-0.5.13-3Kl4d46bfFOKlGDkbjwGGp=08ed2990fe4124043525924df120813a
             http-types-0.12.1-1FEEescNY7H9pB2LVhivNI=b54600906e288a2a11c67e3d97adc11c
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
haddock-interfaces: /usr/share/doc/haskell-authenticate-oauth/html/authenticate-oauth.haddock
haddock-html: /usr/share/doc/haskell-authenticate-oauth/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
